#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['airQ']

package_data = \
{'': ['*'], 'airQ': ['model/*']}

extras_require = \
{'dev': ['flit']}

entry_points = \
{'console_scripts': ['airQ = airQ.app:main']}

setup(name='airQ',
      version='0.2.0',
      description='airQ module initialization point',
      author='Anjan Roy',
      author_email='anjanroy@yandex.com',
      url='https://github.com/itzmeanjan/airQ',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
